'use strict';

var _defineProperty2 = require('babel-runtime/helpers/defineProperty');

var _defineProperty3 = _interopRequireDefault(_defineProperty2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var React = require('react'),
    _require = require('react-redux'),
    Provider = _require.Provider,
    _require2 = require('rebass'),
    withRebass = _require2.withRebass,
    _require3 = require('immutable'),
    Map = _require3.Map,
    _require4 = require('immutable-jsonld'),
    JSONLDNode = _require4.JSONLDNode,
    fromExpandedJSONLD = _require4.fromExpandedJSONLD,
    configureStore = require('./store/configureStore'),
    _require5 = require('./actions'),
    updateUniverse = _require5.updateUniverse,
    updateNode = _require5.updateNode,
    updateOnNewNamedNode = _require5.updateOnNewNamedNode,
    updateMintID = _require5.updateMintID,
    EditNode = require('./containers/EditNode'),
    _require6 = require('./selectors'),
    getNode = _require6.getNode;


var indexByID = function indexByID(nodes) {
  return Map(nodes.map(function (node) {
    return [node.id, node];
  }));
};

var load = function load(json) {
  return indexByID(fromExpandedJSONLD(json));
};

var observeStore = function observeStore(store, select, onChange) {
  var currentState = select(store.getState());

  var handleChange = function handleChange() {
    var nextState = select(store.getState());
    if (!nextState.equals(currentState)) {
      currentState = nextState;
      onChange(currentState);
    }
  };

  return store.subscribe(handleChange);
};

var Editor = React.createClass({
  displayName: 'Editor',
  propTypes: { classes: React.PropTypes.instanceOf(Map),
    properties: React.PropTypes.instanceOf(Map),
    individuals: React.PropTypes.instanceOf(Map),
    datatypes: React.PropTypes.instanceOf(Map),
    languages: React.PropTypes.instanceOf(Map),
    node: React.PropTypes.instanceOf(JSONLDNode),
    mintID: React.PropTypes.func,
    onSave: React.PropTypes.func,
    onNewNamedNode: React.PropTypes.func
  },

  getDefaultProps: function getDefaultProps() {
    return { classes: Map(),
      properties: Map(),
      individuals: Map(),
      datatypes: load(require('./datatypes.json')),
      languages: load(require('./languages.json')),
      node: JSONLDNode(),
      mintID: undefined,
      onSave: function onSave() {},
      onNewNamedNode: function onNewNamedNode() {}
    };
  },

  dispatch: function dispatch(action) {
    this.state.store.dispatch(action);
  },

  getInitialState: function getInitialState() {
    /* eslint-disable no-unused-vars */
    var _props = this.props,
        onSave = _props.onSave,
        className = _props.className,
        style = _props.style,
        theme = _props.theme,
        subComponentStyles = _props.subComponentStyles,
        props = (0, _objectWithoutProperties3.default)(_props, ['onSave', 'className', 'style', 'theme', 'subComponentStyles']);
    /* eslint-enable */

    var store = configureStore((0, _extends3.default)({}, props));
    return { store: store,
      unsubscribe: observeStore(store, getNode, onSave)
    };
  },

  componentWillReceiveProps: function componentWillReceiveProps(next) {
    var current = this.state.store.getState();
    var _arr = ['classes', 'properties', 'individuals', 'datatypes', 'languages'];
    for (var _i = 0; _i < _arr.length; _i++) {
      var domain = _arr[_i];
      if (!next[domain].equals(current[domain])) {
        this.dispatch(updateUniverse((0, _defineProperty3.default)({}, domain, next[domain])));
      }
    }
    if (!next.node.equals(current.node)) {
      this.dispatch(updateNode(next.node));
    }
    if (next.mintID !== current.mintID) {
      this.dispatch(updateMintID(next.mintID));
    }
    if (next.onNewNamedNode !== current.onNewNamedNode) {
      this.dispatch(updateOnNewNamedNode(next.onNewNamedNode));
    }
    if (next.onSave !== current.onSave) {
      this.state.unsubscribe();
      this.setState({ unsubscribe: observeStore(this.state.store, getNode, next.onSave) });
    }
  },

  render: function render() {
    return React.createElement(
      Provider,
      { store: this.state.store },
      React.createElement(EditNode, {
        className: this.props.className,
        style: this.props.style
      })
    );
  }
});

Editor._name = 'Editor';

module.exports = withRebass(Editor);