'use strict';

var React = require('react'),
    test = require('tape'),
    _require = require('enzyme'),
    shallow = _require.shallow,
    Chip = require('../Chip'); // eslint-disable-line no-unused-vars


test('is a div', function (t) {
  var wrapper = shallow(React.createElement(
    Chip,
    null,
    'test'
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.ok(inner.is('div'));
});

test('has a className', function (t) {
  var wrapper = shallow(React.createElement(
    Chip,
    null,
    'test'
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'Chip');
});

test('accepts custom className props', function (t) {
  var wrapper = shallow(React.createElement(
    Chip,
    { className: 'foo' },
    'test'
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'Chip foo');
});

test('accepts custom styles', function (t) {
  var wrapper = shallow(React.createElement(
    Chip,
    { style: { margin: 12 } },
    'test'
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 12);
});

test('context styles override default styles', function (t) {
  var wrapper = shallow(React.createElement(
    Chip,
    null,
    'test'
  ), { context: { rebass: { Chip: { marginLeft: 24 } } } }),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().style.marginLeft, 24);
});

test('style props override context styles', function (t) {
  var wrapper = shallow(React.createElement(
    Chip,
    { m: 0, style: { margin: 12 } },
    'test'
  ), { context: { rebass: { Chip: { margin: 24 } } } }),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 12);
});