'use strict';

var React = require('react'),
    test = require('tape'),
    _require = require('enzyme'),
    shallow = _require.shallow,
    mount = _require.mount,
    _require2 = require('rebass'),
    Dropdown = _require2.Dropdown,
    DropdownMenu = _require2.DropdownMenu,
    Modal = require('../Modal'); // eslint-disable-line no-unused-vars


require('jsdom-global')();

test('is a Dropdown', function (t) {
  var wrapper = shallow(React.createElement(
    Modal,
    null,
    React.createElement(
      'span',
      null,
      'A'
    ),
    React.createElement(
      'span',
      null,
      'B'
    )
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.ok(inner.is(Dropdown));
});

test('has a className', function (t) {
  var wrapper = shallow(React.createElement(
    Modal,
    null,
    React.createElement(
      'span',
      null,
      'A'
    ),
    React.createElement(
      'span',
      null,
      'B'
    )
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'Modal');
});

test('accepts custom className props', function (t) {
  var wrapper = shallow(React.createElement(
    Modal,
    { className: 'foo' },
    React.createElement(
      'span',
      null,
      'A'
    ),
    React.createElement(
      'span',
      null,
      'B'
    )
  )),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'Modal foo');
});

test('accepts custom styles', function (t) {
  var wrapper = mount(React.createElement(
    Modal,
    { style: { margin: 12 } },
    React.createElement(
      'span',
      null,
      'A'
    ),
    React.createElement(
      'span',
      null,
      'B'
    )
  )),
      menu = wrapper.find(DropdownMenu).first();
  t.plan(1);
  t.equal(menu.props().style.margin, 12);
});

test('context styles override default styles', function (t) {
  var wrapper = mount(React.createElement(
    Modal,
    null,
    React.createElement(
      'span',
      null,
      'A'
    ),
    React.createElement(
      'span',
      null,
      'B'
    )
  ), { context: { rebass: { Modal: { marginLeft: 24 } } } }),
      menu = wrapper.find(DropdownMenu).first();
  t.plan(1);
  t.equal(menu.props().style.marginLeft, 24);
});

test('style props override context styles', function (t) {
  var wrapper = mount(React.createElement(
    Modal,
    { m: 0, style: { margin: 12 } },
    React.createElement(
      'span',
      null,
      'A'
    ),
    React.createElement(
      'span',
      null,
      'B'
    )
  ), { context: { rebass: { Modal: { margin: 24 } } } }),
      menu = wrapper.find(DropdownMenu).first();
  t.plan(1);
  t.equal(menu.props().style.margin, 12);
});