'use strict';

var React = require('react'),
    test = require('tape'),
    _require = require('enzyme'),
    shallow = _require.shallow,
    RemoveButton = require('../RemoveButton'); // eslint-disable-line no-unused-vars


test('is a div', function (t) {
  var wrapper = shallow(React.createElement(RemoveButton, null)),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.ok(inner.is('div'));
});

test('has a className', function (t) {
  var wrapper = shallow(React.createElement(RemoveButton, null)),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'RemoveButton');
});

test('accepts custom className props', function (t) {
  var wrapper = shallow(React.createElement(RemoveButton, { className: 'foo' })),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'RemoveButton foo');
});

test('accepts custom styles', function (t) {
  var wrapper = shallow(React.createElement(RemoveButton, { style: { margin: 12 } })),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 12);
});

test('context styles override default styles', function (t) {
  var wrapper = shallow(React.createElement(RemoveButton, null), { context: { rebass: { RemoveButton: { marginLeft: 24 } } } }),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().style.marginLeft, 24);
});

test('style props override context styles', function (t) {
  var wrapper = shallow(React.createElement(RemoveButton, { m: 0, style: { margin: 12 } }), { context: { rebass: { RemoveButton: { margin: 24 } } } }),
      inner = wrapper.first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 12);
});