'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var React = require('react'),
    _require = require('react-redux'),
    connect = _require.connect,
    _require2 = require('redux'),
    bindActionCreators = _require2.bindActionCreators,
    _require3 = require('immutable'),
    List = _require3.List,
    _require4 = require('../selectors'),
    getInput = _require4.getInput,
    getEditPath = _require4.getEditPath,
    getSuggestions = _require4.getSuggestions,
    getPropertySuggester = _require4.getPropertySuggester,
    getProperties = _require4.getProperties,
    getIDMinter = _require4.getIDMinter,
    _require5 = require('../actions'),
    updateEditPath = _require5.updateEditPath,
    updateInput = _require5.updateInput,
    updateSuggestions = _require5.updateSuggestions,
    setIn = _require5.setIn,
    newNamedNode = _require5.newNamedNode,
    Autosuggest = require('../components/Autosuggest'),
    _require6 = require('../namespaces'),
    owl = _require6.owl,
    _require7 = require('../utils'),
    node = _require7.node; // eslint-disable-line no-unused-vars


var mapStateToProps = function mapStateToProps(state) {
  return { input: getInput(state),
    suggestions: getSuggestions(state),
    findSuggestions: getPropertySuggester(state),
    editPath: getEditPath(state),
    mintID: getIDMinter(state),
    propertyCount: getProperties(state).size
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return bindActionCreators({ updateEditPath: updateEditPath,
    updateInput: updateInput,
    updateSuggestions: updateSuggestions,
    setIn: setIn,
    newNamedNode: newNamedNode
  }, dispatch);
};

var nodesToSectionedSuggestions = function nodesToSectionedSuggestions(filter) {
  return function (labels) {
    return function (nodes) {
      return nodes.filter(filter).groupBy(function (node) {
        return node.types.includes(owl('ObjectProperty')) ? 'Relations' : 'Properties';
      }).update('Properties', function (nodes) {
        return nodes ? nodes : List();
      }).update('Relations', function (nodes) {
        return nodes ? nodes : List();
      }).entrySeq().map(function (_ref) {
        var _ref2 = (0, _slicedToArray3.default)(_ref, 2),
            title = _ref2[0],
            nodes = _ref2[1];

        return { title: title,
          suggestions: nodes.map(function (node) {
            return { id: node.id,
              label: labels.get(node.id).value
            };
          }).sort(function (_ref3, _ref4) {
            var a = _ref3.label;
            var b = _ref4.label;
            return a.localeCompare(b);
          }).toArray()
        };
      }).sort(function (_ref5, _ref6) {
        var a = _ref5.title;
        var b = _ref6.title;
        return a.localeCompare(b);
      }).toArray();
    };
  };
};

var mergeProps = function mergeProps(_ref7, _ref8, _ref9) {
  var input = _ref7.input,
      suggestions = _ref7.suggestions,
      findSuggestions = _ref7.findSuggestions,
      editPath = _ref7.editPath,
      mintID = _ref7.mintID,
      propertyCount = _ref7.propertyCount;
  var updateEditPath = _ref8.updateEditPath,
      updateInput = _ref8.updateInput,
      updateSuggestions = _ref8.updateSuggestions,
      setIn = _ref8.setIn,
      newNamedNode = _ref8.newNamedNode;
  var path = _ref9.path,
      exclude = _ref9.exclude,
      props = (0, _objectWithoutProperties3.default)(_ref9, ['path', 'exclude']);
  return (0, _extends3.default)({ name: 'new_property',
    label: 'New property or relation',
    hideLabel: true,
    input: editPath.equals(path) ? input : '',
    suggestions: suggestions,
    onFocus: function onFocus() {
      return updateEditPath(path);
    },
    onBlur: function onBlur() {
      return updateEditPath(path.pop());
    },
    onSuggestionsFetchRequested: function onSuggestionsFetchRequested(_ref10) {
      var value = _ref10.value;

      var _findSuggestions = findSuggestions(value, nodesToSectionedSuggestions(function (suggestion) {
        return !exclude.includes(suggestion.id);
      })),
          _findSuggestions2 = (0, _slicedToArray3.default)(_findSuggestions, 2),
          properties = _findSuggestions2[0],
          relations = _findSuggestions2[1];

      if (value) {
        if (mintID.accepts(owl('ObjectProperty'))) {
          relations.suggestions = [{ label: 'Create relation \u201C' + value + '\u201D',
            type: owl('ObjectProperty'),
            value: value
          }].concat((0, _toConsumableArray3.default)(relations.suggestions));
        }
        if (mintID.accepts(owl('DatatypeProperty'))) {
          properties.suggestions = [{ label: 'Create property \u201C' + value + '\u201D',
            type: owl('DatatypeProperty'),
            value: value
          }].concat((0, _toConsumableArray3.default)(properties.suggestions));
        }
      }
      updateSuggestions([properties, relations].filter(function (_ref11) {
        var suggestions = _ref11.suggestions;
        return suggestions.length > 0;
      }));
    },
    onSuggestionsClearRequested: function onSuggestionsClearRequested() {
      return updateSuggestions([]);
    },
    onSuggestionSelected: function onSuggestionSelected(_, _ref12) {
      var suggestion = _ref12.suggestion;

      var id = suggestion.id;
      if (!id) {
        id = mintID(suggestion.type);
        newNamedNode(node(id, suggestion.value, [suggestion.type]));
      }
      var newPropPath = path.set(-1, id);
      setIn(newPropPath, List(), { editPath: newPropPath.push(0) });
    },
    shouldRenderSuggestions: function shouldRenderSuggestions(value) {
      return propertyCount < 20 || value.trim().length > 0;
    },
    multiSection: true,
    renderSectionTitle: function renderSectionTitle(section) {
      return section.title;
    },
    getSectionSuggestions: function getSectionSuggestions(section) {
      return section.suggestions;
    },
    focused: editPath.equals(path),
    updateInput: updateInput
  }, props);
};

var AddProperty = connect(mapStateToProps, mapDispatchToProps, mergeProps)(Autosuggest);

AddProperty.displayName = 'AddProperty';

module.exports = AddProperty;