'use strict';

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var React = require('react'),
    _require = require('react-redux'),
    connect = _require.connect,
    _require2 = require('redux'),
    bindActionCreators = _require2.bindActionCreators,
    _require3 = require('../selectors'),
    getInput = _require3.getInput,
    getEditPath = _require3.getEditPath,
    getSuggestions = _require3.getSuggestions,
    getClassSuggester = _require3.getClassSuggester,
    getClasses = _require3.getClasses,
    getIDMinter = _require3.getIDMinter,
    _require4 = require('../actions'),
    updateEditPath = _require4.updateEditPath,
    updateInput = _require4.updateInput,
    updateSuggestions = _require4.updateSuggestions,
    pushIn = _require4.pushIn,
    newNamedNode = _require4.newNamedNode,
    Autosuggest = require('../components/Autosuggest'),
    _require5 = require('../utils'),
    node = _require5.node,
    _require6 = require('../namespaces'),
    rdfs = _require6.rdfs; // eslint-disable-line no-unused-vars


var mapStateToProps = function mapStateToProps(state) {
  return { input: getInput(state),
    suggestions: getSuggestions(state),
    findSuggestions: getClassSuggester(state),
    editPath: getEditPath(state),
    mintID: getIDMinter(state),
    classCount: getClasses(state).size
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return bindActionCreators({ updateEditPath: updateEditPath,
    updateInput: updateInput,
    updateSuggestions: updateSuggestions,
    pushIn: pushIn,
    newNamedNode: newNamedNode
  }, dispatch);
};

var mergeProps = function mergeProps(_ref, _ref2, _ref3) {
  var input = _ref.input,
      suggestions = _ref.suggestions,
      findSuggestions = _ref.findSuggestions,
      editPath = _ref.editPath,
      mintID = _ref.mintID,
      classCount = _ref.classCount;
  var updateEditPath = _ref2.updateEditPath,
      updateInput = _ref2.updateInput,
      updateSuggestions = _ref2.updateSuggestions,
      pushIn = _ref2.pushIn,
      newNamedNode = _ref2.newNamedNode;
  var path = _ref3.path,
      exclude = _ref3.exclude,
      props = (0, _objectWithoutProperties3.default)(_ref3, ['path', 'exclude']);
  return (0, _extends3.default)({ name: 'new_type_id',
    label: 'New type',
    mb: 0,
    hideLabel: true,
    input: editPath.equals(path) ? input : '',
    suggestions: suggestions,
    onFocus: function onFocus() {
      return updateEditPath(path);
    },
    onBlur: function onBlur() {
      return updateEditPath(path.pop().pop());
    },
    onSuggestionsFetchRequested: function onSuggestionsFetchRequested(_ref4) {
      var value = _ref4.value;

      var suggestions = findSuggestions(value).filter(function (suggestion) {
        return !exclude.includes(suggestion.id);
      });
      updateSuggestions(value && mintID.accepts(rdfs('Class')) ? [{ label: 'Create type \u201C' + value + '\u201D',
        type: rdfs('Class'),
        value: value
      }].concat((0, _toConsumableArray3.default)(suggestions)) : suggestions);
    },
    onSuggestionsClearRequested: function onSuggestionsClearRequested() {
      return updateSuggestions([]);
    },
    onSuggestionSelected: function onSuggestionSelected(_, _ref5) {
      var suggestion = _ref5.suggestion;

      var id = suggestion.id;
      if (!id) {
        id = mintID(suggestion.type);
        newNamedNode(node(id, suggestion.value, [suggestion.type]));
      }
      pushIn(path.pop(), id, { editPath: path.set(-1, path.last() + 1) });
    },
    shouldRenderSuggestions: function shouldRenderSuggestions(value) {
      return classCount < 20 || value.trim().length > 0;
    },
    focused: editPath.equals(path),
    updateInput: updateInput
  }, props);
};

var AddTypeIdentifier = connect(mapStateToProps, mapDispatchToProps, mergeProps)(Autosuggest);

AddTypeIdentifier.displayName = 'AddTypeIdentifier';

module.exports = AddTypeIdentifier;