'use strict';

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var React = require('react'),
    _require = require('react-redux'),
    connect = _require.connect,
    _require2 = require('redux'),
    bindActionCreators = _require2.bindActionCreators,
    _require3 = require('immutable'),
    List = _require3.List,
    Set = _require3.Set,
    classnames = require('classnames'),
    _require4 = require('rebass'),
    withRebass = _require4.withRebass,
    Panel = _require4.Panel,
    PanelHeader = _require4.PanelHeader,
    PanelFooter = _require4.PanelFooter,
    Block = _require4.Block,
    Heading = _require4.Heading,
    Text = _require4.Text,
    Switch = _require4.Switch,
    Space = _require4.Space,
    FlexRow = require('../components/FlexRow'),
    _require5 = require('../selectors'),
    getNode = _require5.getNode,
    getRootNodePath = _require5.getRootNodePath,
    getLabelResolver = _require5.getLabelResolver,
    getIDMinter = _require5.getIDMinter,
    getProperties = _require5.getProperties,
    isEditingProperties = _require5.isEditingProperties,
    _require6 = require('../actions'),
    toggleEditingProperties = _require6.toggleEditingProperties,
    ShowNode = require('./ShowNode'),
    Type = require('./Type'),
    Property = require('./Property'),
    AddProperty = require('./AddProperty'),
    _require7 = require('../utils'),
    keyFromPath = _require7.keyFromPath,
    labelOrID = _require7.labelOrID,
    _require8 = require('../namespaces'),
    owl = _require8.owl; // eslint-disable-line no-unused-vars


var mapStateToProps = function mapStateToProps(state) {
  return { top: getNode(state),
    path: getRootNodePath(state),
    labelFor: getLabelResolver(state),
    mintID: getIDMinter(state),
    availableProperties: getProperties(state),
    isEditingProperties: isEditingProperties(state)
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return bindActionCreators({ toggleEditingProperties: toggleEditingProperties }, dispatch);
};

var renderPath = function renderPath(top, path, labelFor) {
  return path.reduce(function (_ref, part, index) {
    var subpath = _ref.subpath,
        elements = _ref.elements;
    return { subpath: subpath.push(part),
      elements: elements.push(index % 2 === 0 // alternates between nodes and properties
      ? React.createElement(ShowNode, {
        key: 'path-' + index,
        path: subpath,
        deletable: false,
        mr: 1
      }) : React.createElement(
        Text,
        {
          key: 'path-' + index,
          mr: 1
        },
        labelFor(subpath.last())
      ))
    };
  }, { subpath: List(), elements: List() });
};

var component = function component(_ref2) {
  var top = _ref2.top,
      path = _ref2.path,
      labelFor = _ref2.labelFor,
      mintID = _ref2.mintID,
      availableProperties = _ref2.availableProperties,
      isEditingProperties = _ref2.isEditingProperties,
      toggleEditingProperties = _ref2.toggleEditingProperties,
      className = _ref2.className,
      style = _ref2.style,
      theme = _ref2.theme,
      subComponentStyles = _ref2.subComponentStyles,
      props = (0, _objectWithoutProperties3.default)(_ref2, ['top', 'path', 'labelFor', 'mintID', 'availableProperties', 'isEditingProperties', 'toggleEditingProperties', 'className', 'style', 'theme', 'subComponentStyles']);
  var fontSizes = theme.fontSizes;


  var cx = classnames('EditNode', className);

  var rootStyle = (0, _objectWithoutProperties3.default)(style, []);


  var sx = { root: (0, _extends3.default)({}, rootStyle),
    addProperty: (0, _extends3.default)({ fontSize: fontSizes[4]
    }, subComponentStyles.addProperty)
  };

  var node = top.getIn(path);
  var properties = node.keySeq();

  var canAddProperty = mintID.accepts(owl('DatatypeProperty')) || mintID.accepts(owl('ObjectProperty')) || !Set(availableProperties.keySeq()).subtract(properties).isEmpty();

  return React.createElement(
    Panel,
    (0, _extends3.default)({
      className: cx,
      theme: 'muted',
      style: sx.root
    }, props),
    path.isEmpty() ? '' : React.createElement(
      PanelHeader,
      { theme: 'muted' },
      renderPath(top, path, labelFor).elements
    ),
    React.createElement(
      Heading,
      null,
      labelOrID(node)
    ),
    React.createElement(
      Block,
      { mb: 3 },
      React.createElement(Type, { path: path.push('@type') }),
      node.propertySeq().map(function (_ref3) {
        var _ref4 = (0, _slicedToArray3.default)(_ref3, 1),
            predicate = _ref4[0];

        return React.createElement(Property, keyFromPath(path.push(predicate)));
      }),
      canAddProperty ? React.createElement(AddProperty, (0, _extends3.default)({}, keyFromPath(path.push('new-property-' + properties.count())), {
        exclude: properties,
        mt: 2,
        style: sx.addProperty
      })) : null
    ),
    React.createElement(
      PanelFooter,
      { theme: 'muted' },
      React.createElement(
        FlexRow,
        { mt: 0, margins: { mr: 1 } },
        React.createElement(Switch, {
          checked: isEditingProperties,
          onClick: function onClick() {
            return toggleEditingProperties();
          }
        }),
        React.createElement(
          Text,
          {
            style: { cursor: 'pointer' },
            onClick: function onClick() {
              return toggleEditingProperties();
            }
          },
          isEditingProperties ? 'Editing properties' : 'Edit properties'
        ),
        React.createElement(Space, null)
      )
    )
  );
};

component._name = 'EditNodeComponent';

var EditNode = connect(mapStateToProps, mapDispatchToProps)(withRebass(component));

EditNode.displayName = 'EditNodeContainer';

module.exports = EditNode;