'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var React = require('react'),
    _require = require('react-redux'),
    connect = _require.connect,
    _require2 = require('redux'),
    bindActionCreators = _require2.bindActionCreators,
    _require3 = require('rebass'),
    Input = _require3.Input,
    Block = _require3.Block,
    _require4 = require('immutable'),
    List = _require4.List,
    ShowValue = require('./ShowValue'),
    Modal = require('../components/Modal'),
    Autosuggest = require('../components/Autosuggest'),
    _require5 = require('../selectors'),
    getNode = _require5.getNode,
    getInput = _require5.getInput,
    getSuggestions = _require5.getSuggestions,
    getEditPath = _require5.getEditPath,
    getLanguages = _require5.getLanguages,
    getLabelResolver = _require5.getLabelResolver,
    getDatatypeSuggester = _require5.getDatatypeSuggester,
    getLanguageSuggester = _require5.getLanguageSuggester,
    _require6 = require('../actions'),
    updateEditPath = _require6.updateEditPath,
    updateInput = _require6.updateInput,
    updateSuggestions = _require6.updateSuggestions,
    setIn = _require6.setIn,
    _require7 = require('../namespaces'),
    rdfs = _require7.rdfs,
    lvont = _require7.lvont; // eslint-disable-line no-unused-vars


var mapStateToProps = function mapStateToProps(state, _ref) {
  var path = _ref.path;
  return { value: getNode(state).getIn(path),
    input: getInput(state),
    suggestions: getSuggestions(state),
    editPath: getEditPath(state),
    languages: getLanguages(state),
    labelResolver: getLabelResolver(state),
    findDatatypes: getDatatypeSuggester(state),
    findLanguages: getLanguageSuggester(state)
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return bindActionCreators({ updateEditPath: updateEditPath, updateInput: updateInput, updateSuggestions: updateSuggestions, setIn: setIn }, dispatch);
};

var languageWithTag = function languageWithTag(tag, languages) {
  return languages.find(function (language) {
    return language.get(lvont('iso639P1Code')).first().value === tag;
  });
};

var tagForLanguage = function tagForLanguage(language_id, languages) {
  return languages.get(language_id).get(lvont('iso639P1Code')).first().value;
};

var EditValue = function EditValue(_ref2) {
  var path = _ref2.path,
      value = _ref2.value,
      input = _ref2.input,
      editPath = _ref2.editPath,
      languages = _ref2.languages,
      labelResolver = _ref2.labelResolver,
      findDatatypes = _ref2.findDatatypes,
      findLanguages = _ref2.findLanguages,
      updateEditPath = _ref2.updateEditPath,
      updateSuggestions = _ref2.updateSuggestions,
      setIn = _ref2.setIn,
      props = (0, _objectWithoutProperties3.default)(_ref2, ['path', 'value', 'input', 'editPath', 'languages', 'labelResolver', 'findDatatypes', 'findLanguages', 'updateEditPath', 'updateSuggestions', 'setIn']);


  var valuePath = path.push('@value');
  var typePath = path.push('@type');
  var languagePath = path.push('@language');

  var valueInput = value.value || '';
  var typeInput = value.type ? labelResolver(value.type) : '';
  var languageInput = value.language ? labelResolver(languageWithTag(value.language, languages).id) : '';

  var onTypeSuggestionSelected = function onTypeSuggestionSelected(_, _ref3) {
    var suggestion = _ref3.suggestion;

    var newValue = suggestion.id === undefined ? value.delete('@type') : value.delete('@language').set('@type', suggestion.id);
    setIn(path, newValue, { input: suggestion.label });
  };

  var onLanguageSuggestionSelected = function onLanguageSuggestionSelected(_, _ref4) {
    var suggestion = _ref4.suggestion;

    var newValue = value.delete('@type').set('@language', tagForLanguage(suggestion.id, languages));
    setIn(path, newValue, { input: suggestion.label });
  };

  return React.createElement(
    Modal,
    { onDismiss: function onDismiss() {
        return updateEditPath(List());
      } },
    React.createElement(ShowValue, { path: path, ml: 1, mt: 1 }),
    React.createElement(
      Block,
      { m: 0, p: 1 },
      React.createElement(Input, {
        label: 'value',
        name: valuePath.join('|'),
        value: valueInput,
        onFocus: function onFocus() {
          return updateEditPath(valuePath, valueInput);
        },
        onChange: function onChange(e) {
          return setIn(valuePath, e.target.value);
        }
      }),
      React.createElement(Autosuggest, (0, _extends3.default)({
        name: 'type',
        label: 'type',
        input: editPath.equals(typePath) ? input : typeInput,
        onFocus: function onFocus() {
          return updateEditPath(typePath, typeInput);
        },
        onBlur: function onBlur() {
          return updateEditPath(path);
        },
        onSuggestionsFetchRequested: function onSuggestionsFetchRequested(_ref5) {
          var value = _ref5.value;
          return updateSuggestions([{ label: 'none' }].concat((0, _toConsumableArray3.default)(findDatatypes(value).filter(function (_ref6) {
            var id = _ref6.id;
            return id !== rdfs('Literal');
          }))));
        },
        onSuggestionsClearRequested: function onSuggestionsClearRequested() {
          return updateSuggestions([]);
        },
        onSuggestionSelected: onTypeSuggestionSelected,
        shouldRenderSuggestions: function shouldRenderSuggestions() {
          return true;
        },
        focused: editPath.equals(typePath)
      }, props)),
      value.type === undefined ? React.createElement(Autosuggest, (0, _extends3.default)({
        name: 'language',
        label: 'language',
        input: editPath.equals(languagePath) ? input : languageInput,
        onFocus: function onFocus() {
          return updateEditPath(languagePath, languageInput);
        },
        onBlur: function onBlur() {
          return updateEditPath(path);
        },
        onSuggestionsFetchRequested: function onSuggestionsFetchRequested(_ref7) {
          var value = _ref7.value;
          return updateSuggestions(findLanguages(value));
        },
        onSuggestionsClearRequested: function onSuggestionsClearRequested() {
          return updateSuggestions([]);
        },
        onSuggestionSelected: onLanguageSuggestionSelected,
        focused: editPath.equals(languagePath)
      }, props)) : ''
    )
  );
};

module.exports = connect(mapStateToProps, mapDispatchToProps)(EditValue);