'use strict';

var React = require('react'),
    _require = require('redux'),
    bindActionCreators = _require.bindActionCreators,
    _require2 = require('react-redux'),
    connect = _require2.connect,
    _require3 = require('immutable'),
    List = _require3.List,
    _require4 = require('rebass'),
    Text = _require4.Text,
    _require5 = require('immutable-jsonld'),
    JSONLDValue = _require5.JSONLDValue,
    _require6 = require('../actions'),
    updateEditPath = _require6.updateEditPath,
    deleteIn = _require6.deleteIn,
    _require7 = require('../selectors'),
    getNode = _require7.getNode,
    getLabelResolver = _require7.getLabelResolver,
    getProperties = _require7.getProperties,
    isEditingProperties = _require7.isEditingProperties,
    _require8 = require('../utils'),
    keyFromPath = _require8.keyFromPath,
    FlexRow = require('../components/FlexRow'),
    RemoveButton = require('../components/RemoveButton'),
    Value = require('./Value'),
    ShowNode = require('./ShowNode'),
    AddValue = require('./AddValue'),
    AddNode = require('./AddNode'),
    _require9 = require('../namespaces'),
    owl = _require9.owl; // eslint-disable-line no-unused-vars


var isObjectProperty = function isObjectProperty(properties) {
  return function (predicate) {
    return properties.has(predicate) ? properties.get(predicate).types.includes(owl('ObjectProperty')) : true;
  };
};

var mapStateToProps = function mapStateToProps(state, _ref) {
  var path = _ref.path;

  var id = path.last();
  return { id: id,
    label: getLabelResolver(state)(id),
    objects: getNode(state).getIn(path, List()),
    isObjectProperty: isObjectProperty(getProperties(state))(id),
    deletable: isEditingProperties(state)
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return bindActionCreators({ updateEditPath: updateEditPath, deleteIn: deleteIn }, dispatch);
};

var mergeProps = function mergeProps(_ref2, _ref3, _ref4) {
  var id = _ref2.id,
      label = _ref2.label,
      objects = _ref2.objects,
      isObjectProperty = _ref2.isObjectProperty,
      deletable = _ref2.deletable;
  var updateEditPath = _ref3.updateEditPath,
      deleteIn = _ref3.deleteIn;
  var path = _ref4.path;

  var children = [React.createElement(
    Text,
    null,
    label
  ), objects.isEmpty() ? null : objects.map(function (o, i) {
    return React.createElement(JSONLDValue.isJSONLDValue(o) ? Value : ShowNode, keyFromPath(path.push(i)));
  }), React.createElement(isObjectProperty ? AddNode : AddValue, keyFromPath(path.push(objects.count())))];
  return { children: deletable ? [React.createElement(RemoveButton, {
      color: 'red',
      style: { paddingTop: '4px' },
      onClick: function onClick() {
        return deleteIn(path);
      }
    })].concat(children) : children
  };
};

var Property = connect(mapStateToProps, mapDispatchToProps, mergeProps)(FlexRow);

Property.displayName = 'Property';

module.exports = Property;