'use strict';

var React = require('react'),
    _require = require('redux'),
    bindActionCreators = _require.bindActionCreators,
    _require2 = require('react-redux'),
    connect = _require2.connect,
    _require3 = require('immutable'),
    List = _require3.List,
    _require4 = require('rebass'),
    Text = _require4.Text,
    _require5 = require('immutable-jsonld'),
    JSONLDValue = _require5.JSONLDValue,
    _require6 = require('../actions'),
    updateEditPath = _require6.updateEditPath,
    _require7 = require('../selectors'),
    getNode = _require7.getNode,
    getLabelResolver = _require7.getLabelResolver,
    getProperties = _require7.getProperties,
    _require8 = require('../utils'),
    keyFromPath = _require8.keyFromPath,
    FlexRow = require('../components/FlexRow'),
    Value = require('../containers/Value'),
    ShowNode = require('../containers/ShowNode'),
    AddValue = require('../containers/AddValue'),
    AddNode = require('../containers/AddNode'),
    _require9 = require('../namespaces'),
    owl = _require9.owl; // eslint-disable-line no-unused-vars


var isDatatypeProperty = function isDatatypeProperty(properties) {
  return function (predicate) {
    return properties.has(predicate) ? properties.get(predicate).types.includes(owl('DatatypeProperty')) : true;
  };
};

var mapStateToProps = function mapStateToProps(state, _ref) {
  var path = _ref.path;

  var id = path.last();
  return { id: id,
    label: getLabelResolver(state)(id),
    objects: getNode(state).getIn(path, List()),
    isDatatypeProperty: isDatatypeProperty(getProperties(state))(id)
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return bindActionCreators({ updateEditPath: updateEditPath }, dispatch);
};

var mergeProps = function mergeProps(_ref2, _ref3, _ref4) {
  var id = _ref2.id,
      label = _ref2.label,
      objects = _ref2.objects,
      isDatatypeProperty = _ref2.isDatatypeProperty;
  var updateEditPath = _ref3.updateEditPath;
  var path = _ref4.path;
  return {
    children: [React.createElement(
      Text,
      {
        onClick: function onClick() {
          return updateEditPath(path);
        },
        style: { cursor: 'pointer' }
      },
      label
    ), objects.map(function (o, i) {
      return React.createElement(JSONLDValue.isJSONLDValue(o) ? Value : ShowNode, keyFromPath(path.push(i)));
    }), React.createElement(isDatatypeProperty ? AddValue : AddNode, keyFromPath(path.push(objects.count())))]
  };
};

var ShowProperty = connect(mapStateToProps, mapDispatchToProps, mergeProps)(FlexRow);

ShowProperty.displayName = 'ShowProperty';

module.exports = ShowProperty;