'use strict';

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var React = require('react'),
    _require = require('react-dom'),
    render = _require.render,
    _require2 = require('immutable'),
    Map = _require2.Map,
    List = _require2.List,
    _require3 = require('./utils'),
    node = _require3.node,
    value = _require3.value,
    Editor = require('./Editor'),
    _require4 = require('./namespaces'),
    rdfs = _require4.rdfs,
    owl = _require4.owl,
    xsd = _require4.xsd,
    ns = require('rdf-ns'),
    foaf = ns('http://xmlns.com/foaf/0.1/'),
    ex = ns('http://example.org/ns/'),
    uuid = require('node-uuid'); // eslint-disable-line no-unused-vars


var mount = document.createElement('div');
document.body.appendChild(mount);

var Person = node(foaf('Person'), 'Person');
var Project = node(foaf('Project'), 'Project');
var Group = node(foaf('Group'), 'Group');
var classes = Map.of(Person.id, Person, Project.id, Project, Group.id, Group);

var name = node(foaf('name'), 'name').set('@type', List.of(owl('DatatypeProperty')));
var knows = node(foaf('knows'), 'knows').set('@type', List.of(owl('ObjectProperty')));
var member = node(ex('member'), 'member of').set('@type', List.of(owl('ObjectProperty'))).set(rdfs('range'), List.of(Group));
var age = node(foaf('age'), 'age').set('@type', List.of(owl('DatatypeProperty'))).set(rdfs('range'), List.of(node(xsd('decimal'))));
var properties = Map.of(name.id, name, knows.id, knows, member.id, member, age.id, age);

var Kim = node('http://viaf.org/viaf/100935834', 'Kim').set('@type', List.of(Person.id)).set(name.id, List.of('Kim', 'キム').map(value));
var Kanye = node('http://viaf.org/viaf/61794068', 'Kanye').set('@type', List.of(Person.id)).set(name.id, List.of('Kanye', 'Yeezy', 'Yeezus').map(value)).set(knows.id, List.of(Kim)).set(age.id, List());
var Kimye = node('http://example.org/name/Kimye', 'Kimye').set('@type', List.of(Group.id)).set(name.id, List.of('Kimye').map(value));
var individuals = Map.of(Kanye.id, Kanye, Kim.id, Kim, Kimye.id, Kimye);

var mintID = function mintID() {
  var _window$location = window.location,
      protocol = _window$location.protocol,
      hostname = _window$location.hostname;

  return protocol + '//' + hostname + '/.well-known/genid/' + uuid.v4();
};

render(React.createElement(
  'div',
  null,
  React.createElement(Editor, {
    node: Kanye,
    classes: classes,
    properties: properties,
    individuals: individuals,
    mintID: mintID,
    onSave: function onSave(node) {
      return console.log((0, _stringify2.default)(node.toJS(), null, 2));
    },
    onNewNamedNode: function onNewNamedNode(node) {
      return console.log(node.toJS());
    }
  })
), mount);