'use strict';

var test = require('tape'),
    _require = require('immutable'),
    Map = _require.Map,
    List = _require.List,
    reducer = require('../individuals'),
    _require2 = require('../../actions'),
    UPDATE_UNIVERSE = _require2.UPDATE_UNIVERSE,
    NEW_NAMED_NODE = _require2.NEW_NAMED_NODE,
    _require3 = require('../../utils'),
    node = _require3.node,
    _require4 = require('../../namespaces'),
    owl = _require4.owl,
    rdfs = _require4.rdfs,
    ns = require('rdf-ns'),
    ex = ns('http://example.org/ns/');


test('default individuals is empty Map', function (t) {
  t.plan(1);
  t.ok(reducer(undefined, {}).equals(Map()));
});

test('is empty Map after update without individuals', function (t) {
  t.plan(1);
  t.ok(reducer(undefined, { type: UPDATE_UNIVERSE }).equals(Map()));
});

test('is updated after update with individuals', function (t) {
  var Test = node(ex('Test'), 'Test');
  var individuals = Map.of(Test.id, Test);
  t.plan(1);
  t.ok(reducer(undefined, { type: UPDATE_UNIVERSE, individuals: individuals }).equals(individuals));
});

test('new datatype individuals do not get added', function (t) {
  var newProperty = node(ex('a'), 'a').set('@type', List.of(owl('DatatypeProperty')));
  t.plan(1);
  t.false(reducer(Map(), { type: NEW_NAMED_NODE, node: newProperty }).has(newProperty.id));
});

test('new object individuals do not get added', function (t) {
  var newProperty = node(ex('a'), 'a').set('@type', List.of(owl('ObjectProperty')));
  t.plan(1);
  t.false(reducer(Map(), { type: NEW_NAMED_NODE, node: newProperty }).has(newProperty.id));
});

test('new classes do not get added', function (t) {
  var newClass = node(ex('a'), 'a').set('@type', List.of(rdfs('Class')));
  t.plan(1);
  t.false(reducer(Map(), { type: NEW_NAMED_NODE, node: newClass }).has(newClass.id));
});

test('untyped named nodes do get added', function (t) {
  var newNode = node(ex('a'), 'a');
  t.plan(1);
  t.ok(reducer(Map(), { type: NEW_NAMED_NODE, node: newNode }).has(newNode.id));
});

test('typed named nodes do get added', function (t) {
  var newNode = node(ex('a'), 'a').set('@type', List.of(ex('Foo'), ex('Bar')));
  t.plan(1);
  t.ok(reducer(Map(), { type: NEW_NAMED_NODE, node: newNode }).has(newNode.id));
});

test('blank nodes do not get added', function (t) {
  var newNode = node(undefined, 'blank');
  t.plan(1);
  t.false(reducer(Map(), { type: NEW_NAMED_NODE, node: newNode }).has(undefined));
});