'use strict';

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var test = require('tape'),
    _require = require('immutable'),
    Set = _require.Set,
    reducer = require('../mintID'),
    _require2 = require('../../actions'),
    UPDATE_MINT_ID = _require2.UPDATE_MINT_ID,
    _require3 = require('../../namespaces'),
    owl = _require3.owl,
    rdfs = _require3.rdfs;


test('default mintID is a no-op that accepts nothing', function (t) {
  t.plan(6);
  var f = reducer(undefined, {});
  t.equal(typeof f === 'undefined' ? 'undefined' : (0, _typeof3.default)(f), 'function');
  t.false(f.accepts(owl('ObjectProperty')));
  t.false(f.accepts(owl('DatatypeProperty')));
  t.false(f.accepts(rdfs('Class')));
  t.false(f.accepts(rdfs('Resource')));
  t.equal(f(), undefined);
});

test('mintID is updated on UPDATE_MINT_ID', function (t) {
  var action = { type: UPDATE_MINT_ID, mintID: function mintID() {
      return 'id';
    } };
  t.plan(1);
  t.equal(reducer(undefined, action), action.mintID);
});

test('mintID is not updated otherwise', function (t) {
  var action = { mintID: function mintID() {
      return 'id';
    } };
  t.plan(1);
  t.notEqual(reducer(undefined, action), action.mintID);
});

test('if not otherwise specified an initial mintID accepts everything', function (t) {
  var f = function f() {
    return 'id';
  };
  t.plan(5);
  t.equal(reducer(f, {}), f);
  t.ok(f.accepts(owl('ObjectProperty')));
  t.ok(f.accepts(owl('DatatypeProperty')));
  t.ok(f.accepts(rdfs('Class')));
  t.ok(f.accepts(rdfs('Resource')));
});

test('if not otherwise specified an updated mintID accepts everything', function (t) {
  var f = function f() {
    return 'id';
  };
  var action = { type: UPDATE_MINT_ID, mintID: f };
  t.plan(5);
  t.equal(reducer(undefined, action), f);
  t.ok(f.accepts(owl('ObjectProperty')));
  t.ok(f.accepts(owl('DatatypeProperty')));
  t.ok(f.accepts(rdfs('Class')));
  t.ok(f.accepts(rdfs('Resource')));
});

test('a supplied mintID can limit what it accepts', function (t) {
  var f = function f() {
    return 'id';
  };
  f.accepts = function (type) {
    return type === owl('DatatypeProperty');
  };
  var action = { type: UPDATE_MINT_ID, mintID: f };
  t.plan(5);
  t.equal(reducer(undefined, action), f);
  t.false(f.accepts(owl('ObjectProperty')));
  t.ok(f.accepts(owl('DatatypeProperty')));
  t.false(f.accepts(rdfs('Class')));
  t.false(f.accepts(rdfs('Resource')));
});