'use strict';

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var test = require('tape'),
    reducer = require('../onNewNamedNode'),
    _require = require('../../actions'),
    NEW_NAMED_NODE = _require.NEW_NAMED_NODE,
    UPDATE_ON_NEW_NAMED_NODE = _require.UPDATE_ON_NEW_NAMED_NODE,
    _require2 = require('../../utils'),
    node = _require2.node,
    ns = require('rdf-ns'),
    ex = ns('http://example.org/ns/');


test('default onNewNamedNode is a function', function (t) {
  t.plan(1);
  t.equal((0, _typeof3.default)(reducer(undefined, {})), 'function');
});

test('onNewNamedNode is updated on UPDATE_ON_NEW_NAMED_NODE', function (t) {
  var f = function f() {};
  var action = { type: UPDATE_ON_NEW_NAMED_NODE, onNewNamedNode: f };
  t.plan(1);
  t.equal(reducer(undefined, action), f);
});

test('cannot set onNewNamedNode to undefined', function (t) {
  var action = { type: UPDATE_ON_NEW_NAMED_NODE };
  t.plan(1);
  t.equal((0, _typeof3.default)(reducer(undefined, action)), 'function');
});

test('onNewNamedNode is not updated otherwise', function (t) {
  var f = function f() {};
  var action = { onNewNamedNode: f };
  t.plan(1);
  t.notEqual(reducer(undefined, action), f);
});

test('onNewNamedNode is called on NEW_NAMED_NODE', function (t) {
  var action = { type: NEW_NAMED_NODE, node: node(ex('test'), 'test') };
  var f = function f(node) {
    t.equal(node, action.node);
    t.end();
  };
  reducer(f, action);
});

test('onNewNamedNode is not called otherwise', function (t) {
  reducer(function () {
    return t.fail('should not have been called');
  }, {});
  t.end();
});