'use strict';

var test = require('tape'),
    _require = require('immutable'),
    Map = _require.Map,
    List = _require.List,
    reducer = require('../properties'),
    _require2 = require('../../actions'),
    UPDATE_UNIVERSE = _require2.UPDATE_UNIVERSE,
    NEW_NAMED_NODE = _require2.NEW_NAMED_NODE,
    _require3 = require('../../utils'),
    node = _require3.node,
    _require4 = require('../../namespaces'),
    owl = _require4.owl,
    rdfs = _require4.rdfs,
    ns = require('rdf-ns'),
    ex = ns('http://example.org/ns/');


test('default properties includes rdfs:label', function (t) {
  t.plan(1);
  t.ok(reducer(undefined, {}).has(rdfs('label')));
});

test('rdfs:label gets added to initial properties', function (t) {
  t.plan(1);
  t.ok(reducer(Map(), {}).has(rdfs('label')));
});

test('includes rdfs:label after update without properties', function (t) {
  t.plan(1);
  t.ok(reducer(undefined, { type: UPDATE_UNIVERSE }).has(rdfs('label')));
});

test('includes rdfs:label after update with properties', function (t) {
  t.plan(1);
  t.ok(reducer(undefined, { type: UPDATE_UNIVERSE, properties: Map() }).has(rdfs('label')));
});

test('new datatype properties get added', function (t) {
  var newProperty = node(ex('a'), 'a').set('@type', List.of(owl('DatatypeProperty')));
  t.plan(1);
  t.ok(reducer(Map(), { type: NEW_NAMED_NODE, node: newProperty }).has(newProperty.id));
});

test('new object properties get added', function (t) {
  var newProperty = node(ex('a'), 'a').set('@type', List.of(owl('ObjectProperty')));
  t.plan(1);
  t.ok(reducer(Map(), { type: NEW_NAMED_NODE, node: newProperty }).has(newProperty.id));
});

test('new classes do not get added', function (t) {
  var newClass = node(ex('a'), 'a').set('@type', List.of(rdfs('Class')));
  t.plan(1);
  t.false(reducer(Map(), { type: NEW_NAMED_NODE, node: newClass }).has(newClass.id));
});

test('other named nodes do not get added', function (t) {
  var newNode = node(ex('a'), 'a');
  t.plan(1);
  t.false(reducer(Map(), { type: NEW_NAMED_NODE, node: newNode }).has(newNode.id));
});