'use strict';

var _require = require('reselect'),
    createSelector = _require.createSelector,
    _require2 = require('immutable'),
    Map = _require2.Map,
    List = _require2.List,
    Seq = _require2.Seq,
    _require3 = require('immutable-jsonld'),
    JSONLDNode = _require3.JSONLDNode,
    JSONLDValue = _require3.JSONLDValue,
    _require4 = require('../namespaces'),
    rdfs = _require4.rdfs,
    owl = _require4.owl;

var getNode = function getNode(state) {
  return state.node;
};
var getClasses = function getClasses(state) {
  return state.classes;
};
var getProperties = function getProperties(state) {
  return state.properties;
};
var getIndividuals = function getIndividuals(state) {
  return state.individuals;
};
var getDatatypes = function getDatatypes(state) {
  return state.datatypes;
};
var getLanguages = function getLanguages(state) {
  return state.languages;
};
var getIDMinter = function getIDMinter(state) {
  return state.mintID;
};

exports.getNode = getNode;
exports.getClasses = getClasses;
exports.getProperties = getProperties;
exports.getIndividuals = getIndividuals;
exports.getLanguages = getLanguages;
exports.getIDMinter = getIDMinter;

var getLabels = createSelector([getClasses, getProperties, getIndividuals, getDatatypes, getLanguages], function () {
  for (var _len = arguments.length, domains = Array(_len), _key = 0; _key < _len; _key++) {
    domains[_key] = arguments[_key];
  }

  return Map(Seq(domains).flatMap(function (domain) {
    return domain.valueSeq();
  }).map(function (node) {
    return [node.id, node.preferredLabel()];
  }));
});

exports.getLabelResolver = createSelector([getLabels], function (labels) {
  return function (id) {
    return labels.has(id) ? labels.get(id).value : id;
  };
});

var getEditPath = function getEditPath(state) {
  return state.editPath;
};
var getRootNodePath = function getRootNodePath(state) {
  return state.rootNodePath;
};
var getInput = function getInput(state) {
  return state.input;
};
var getSuggestions = function getSuggestions(state) {
  return state.suggestions;
};
var isEditingProperties = function isEditingProperties(state) {
  return state.isEditingProperties;
};

exports.getEditPath = getEditPath;
exports.getRootNodePath = getRootNodePath;
exports.getInput = getInput;
exports.getSuggestions = getSuggestions;
exports.isEditingProperties = isEditingProperties;

var matches = function matches(inputValue, inputLength) {
  return function (label) {
    return label ? label.value.toLowerCase().slice(0, inputLength) === inputValue : false;
  };
};

var findMatchingNodes = function findMatchingNodes(input, domain, labels) {
  var alwaysSuggest = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;

  var inputValue = String(input).trim().toLowerCase();
  var inputLength = inputValue.length;
  var matchesInput = matches(inputValue, inputLength);
  var matchingNodes = inputLength === 0 ? alwaysSuggest ? domain.valueSeq() : Seq() : domain.valueSeq().filter(function (node) {
    return matchesInput(labels.get(node.id));
  });
  return matchingNodes;
};

var nodesToSingleSectionSuggestions = function nodesToSingleSectionSuggestions(labels) {
  return function (nodes) {
    return nodes.map(function (node) {
      return { id: node.id, label: labels.get(node.id).value };
    }).sort(function (_ref, _ref2) {
      var a = _ref.label;
      var b = _ref2.label;
      return a.localeCompare(b);
    }).toArray();
  };
};

var createSuggester = function createSuggester(getter, alwaysSuggest) {
  return createSelector([getter, getLabels], function (resources, labels) {
    return function (input) {
      var nodesToSuggestions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : nodesToSingleSectionSuggestions;
      return nodesToSuggestions(labels)(findMatchingNodes(input, resources, labels, alwaysSuggest));
    };
  });
};

exports.getClassSuggester = createSuggester(getClasses, true);
exports.getPropertySuggester = createSuggester(getProperties, true);
exports.getIndividualSuggester = createSuggester(getIndividuals);
exports.getDatatypeSuggester = createSuggester(getDatatypes, true);
exports.getLanguageSuggester = createSuggester(getLanguages);

var createObject = function createObject(property) {
  var types = property.get(rdfs('range'), List()).map(function (node) {
    return node.id;
  });
  return property.types.includes(owl('DatatypeProperty')) ? JSONLDValue().set('@type', types.first()) : JSONLDNode().set('@type', types);
};

exports.getEmptyObjectCreator = createSelector([getProperties], function (properties) {
  return function (predicate) {
    return properties.has(predicate) ? createObject(properties.get(predicate)) : JSONLDValue();
  };
});

exports.getPredicateRangeFinder = createSelector([getProperties], function (properties) {
  return function (predicate) {
    return properties.has(predicate) ? properties.get(predicate).get(rdfs('range'), List()).map(function (node) {
      return node.id;
    }) : List();
  };
});