'use strict';

var React = require('react'),
    test = require('tape'),
    _require = require('react-redux'),
    Provider = _require.Provider,
    _require2 = require('immutable'),
    Map = _require2.Map,
    _require3 = require('enzyme'),
    shallow = _require3.shallow,
    mount = _require3.mount,
    Editor = require('../Editor'),
    EditNode = require('../containers/EditNode'),
    AddProperty = require('../containers/AddProperty'),
    AddTypeIdentifier = require('../containers/AddTypeIdentifier'),
    _require4 = require('../utils'),
    node = _require4.node,
    _require5 = require('../namespaces'),
    rdfs = _require5.rdfs,
    owl = _require5.owl,
    ns = require('rdf-ns'),
    ex = ns('http://example.org/ns/'); // eslint-disable-line no-unused-vars


require('jsdom-global')();

test('is an EditNode inside a Provider', function (t) {
  var wrapper = shallow(React.createElement(Editor, null)),
      provider = wrapper.first().shallow(),
      inner = provider.first().shallow();
  t.plan(2);
  t.ok(provider.is(Provider));
  t.ok(inner.is(EditNode));
});

test('accepts custom className props', function (t) {
  var wrapper = shallow(React.createElement(Editor, { className: 'foo' })),
      inner = wrapper.first().shallow().first().shallow();
  t.plan(1);
  t.equal(inner.props().className, 'foo');
});

test('accepts Rebass props', function (t) {
  var wrapper = shallow(React.createElement(Editor, { m: 4 })),
      inner = wrapper.first().shallow().first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 64);
});

test('accepts custom styles', function (t) {
  var wrapper = shallow(React.createElement(Editor, { style: { margin: 48 } })),
      inner = wrapper.first().shallow().first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 48);
});

test('context styles override default styles', function (t) {
  var wrapper = shallow(React.createElement(Editor, null), { context: { rebass: { Editor: { marginLeft: 66 } } } }),
      inner = wrapper.first().shallow().first().shallow();
  t.plan(1);
  t.equal(inner.props().style.marginLeft, 66);
});

test('style props override context styles', function (t) {
  var wrapper = shallow(React.createElement(Editor, { m: 0, style: { margin: 12 } }), { context: { rebass: { Editor: { margin: 24 } } } }),
      inner = wrapper.first().shallow().first().shallow();
  t.plan(1);
  t.equal(inner.props().style.margin, 12);
});

test('do not show AddProperty if no unused properties or mintID', function (t) {
  var n = node(ex('Test'), 'Test');
  var wrapper = mount(React.createElement(Editor, { node: n }));
  t.plan(1);
  t.equal(wrapper.find(AddProperty).length, 0);
});

test('do show AddProperty if has properties', function (t) {
  var p = node(ex('test'), 'test', [owl('DatatypeProperty')]);
  var wrapper = mount(React.createElement(Editor, { properties: Map.of(p.id, p) }));
  t.plan(1);
  t.equal(wrapper.find(AddProperty).length, 1);
});

test('do show AddProperty if has mintID', function (t) {
  var wrapper = mount(React.createElement(Editor, { mintID: function mintID() {
      return 'new-id';
    } }));
  t.plan(1);
  t.equal(wrapper.find(AddProperty).length, 1);
});

test('do not show AddTypeIdentifier if no classes or mintID', function (t) {
  var wrapper = mount(React.createElement(Editor, null));
  t.plan(1);
  t.equal(wrapper.find(AddTypeIdentifier).length, 0);
});

test('do not show AddTypeIdentifier if no unused classes or mintID', function (t) {
  var c = node(ex('SomeClass'), 'SomeClass', [rdfs('Class')]);
  var n = node(ex('Test'), 'Test', [c.id]);
  var wrapper = mount(React.createElement(Editor, { node: n, classes: Map.of(c.id, c) }));
  t.plan(1);
  t.equal(wrapper.find(AddTypeIdentifier).length, 0);
});

test('do show AddTypeIdentifier if has classes', function (t) {
  var c = node(ex('Test'), 'Test', [rdfs('Class')]);
  var wrapper = mount(React.createElement(Editor, { classes: Map.of(c.id, c) }));
  t.plan(1);
  t.equal(wrapper.find(AddTypeIdentifier).length, 1);
});

test('do show AddTypeIdentifier if has mintID', function (t) {
  var wrapper = mount(React.createElement(Editor, { mintID: function mintID() {
      return 'new-id';
    } }));
  t.plan(1);
  t.equal(wrapper.find(AddTypeIdentifier).length, 1);
});