'use strict';

var test = require('tape'),
    _require = require('immutable'),
    List = _require.List,
    _require2 = require('immutable-jsonld'),
    JSONLDNode = _require2.JSONLDNode,
    _require3 = require('../actions'),
    updateNode = _require3.updateNode,
    pushIn = _require3.pushIn;


test('node reducer on updateNode', function (t) {
  var reducer = require('../reducers/node');
  t.plan(1);

  var node = JSONLDNode().set('@id', 'foo');
  t.ok(reducer(undefined, updateNode(node)).equals(node));
});

test('node reducer on pushIn', function (t) {
  var reducer = require('../reducers/node');
  t.plan(2);

  t.ok(reducer(undefined, pushIn(List.of('@type'), 'thing')).get('@type').equals(List.of('thing')));

  var path = List.of('a', 0, '@type');
  t.ok(reducer(JSONLDNode().push('a', JSONLDNode()), pushIn(path, 'thing')).getIn(path).equals(List.of('thing')));
});

test('editPath reducer on pushIn', function (t) {
  var reducer = require('../reducers/editPath');
  t.plan(1);

  t.ok(reducer(undefined, pushIn(List.of('@type'), 'thing', { editPath: List.of('foo', 'bar') })).equals(List.of('foo', 'bar')));
});

test('input reducer on pushIn', function (t) {
  var reducer = require('../reducers/input');
  t.plan(1);

  t.equal(reducer('blah', pushIn(List.of('@type'), 'thing')), '');
});